parserFwk.pyparsing.RecursiveGrammarException

Package parserFwk :: Module pyparsing :: Class RecursiveGrammarException |
[frames | no frames]

## Class RecursiveGrammarException

    Exception --+
                |
               RecursiveGrammarException

exception thrown by validate() if the grammar could be improperly recursive

Method Summary
| `__init__(self, parseElementList)`
| `__str__(self)`
Inherited from `Exception`: `__getitem__`

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net